package Bundle::Compress::Zlib;

use strict;

$Bundle::Compress::Zlib::VERSION = '2.072';

1;
__END__

=head1 NAME

Bundle::Compress::Zlib - Install Compress::Zlib and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Compress::Zlib'

=head1 CONTENTS

Scalar::Util

Compress::Raw::Zlib 2.072

Compress::Raw::Bzip2 2.072

Compress::Zlib 2.072

=head1 AUTHOR

Version <= 0.3 Kevin W. Henwood, <Khen1950fx@aol.com>
Version > 0.3  Paul Marquess <pmqs@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood
Copyright (C) 2008-2017 by Paul Marquess

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.

=cut

1;
